summaryrefslogtreecommitdiffstats
path: root/sys/gnu
diff options
context:
space:
mode:
authorphk <phk@FreeBSD.org>2004-06-16 09:47:26 +0000
committerphk <phk@FreeBSD.org>2004-06-16 09:47:26 +0000
commitdfd1f7fd50fffaf75541921fcf86454cd8eb3614 (patch)
tree624c885995e84df6decddd3291c60a15e50e3c85 /sys/gnu
parentcafb94bcea1cdf048e81b7eb2d24808e1a8c5280 (diff)
downloadFreeBSD-src-dfd1f7fd50fffaf75541921fcf86454cd8eb3614.zip
FreeBSD-src-dfd1f7fd50fffaf75541921fcf86454cd8eb3614.tar.gz
Do the dreaded s/dev_t/struct cdev */
Bump __FreeBSD_version accordingly.
Diffstat (limited to 'sys/gnu')
-rw-r--r--sys/gnu/ext2fs/ext2_extern.h4
-rw-r--r--sys/gnu/ext2fs/ext2_ihash.c4
-rw-r--r--sys/gnu/ext2fs/ext2_mount.h2
-rw-r--r--sys/gnu/ext2fs/ext2_vfsops.c8
-rw-r--r--sys/gnu/ext2fs/inode.h4
-rw-r--r--sys/gnu/fs/ext2fs/ext2_extern.h4
-rw-r--r--sys/gnu/fs/ext2fs/ext2_mount.h2
-rw-r--r--sys/gnu/fs/ext2fs/ext2_vfsops.c8
-rw-r--r--sys/gnu/fs/ext2fs/inode.h4
9 files changed, 20 insertions, 20 deletions
diff --git a/sys/gnu/ext2fs/ext2_extern.h b/sys/gnu/ext2fs/ext2_extern.h
index 12ec524..45ba6b3 100644
--- a/sys/gnu/ext2fs/ext2_extern.h
+++ b/sys/gnu/ext2fs/ext2_extern.h
@@ -59,11 +59,11 @@ void ext2_dirbad(struct inode *ip, doff_t offset, char *how);
void ext2_ei2i(struct ext2_inode *, struct inode *);
int ext2_getlbns(struct vnode *, int32_t, struct indir *, int *);
void ext2_i2ei(struct inode *, struct ext2_inode *);
-int ext2_ihashget(dev_t, ino_t, int, struct vnode **);
+int ext2_ihashget(struct cdev *, ino_t, int, struct vnode **);
void ext2_ihashinit(void);
void ext2_ihashins(struct inode *);
struct vnode *
- ext2_ihashlookup(dev_t, ino_t);
+ ext2_ihashlookup(struct cdev *, ino_t);
void ext2_ihashrem(struct inode *);
void ext2_ihashuninit(void);
void ext2_itimes(struct vnode *vp);
diff --git a/sys/gnu/ext2fs/ext2_ihash.c b/sys/gnu/ext2fs/ext2_ihash.c
index 09da056..fca9a0d 100644
--- a/sys/gnu/ext2fs/ext2_ihash.c
+++ b/sys/gnu/ext2fs/ext2_ihash.c
@@ -80,7 +80,7 @@ ext2_ihashuninit()
*/
struct vnode *
ext2_ihashlookup(dev, inum)
- dev_t dev;
+ struct cdev *dev;
ino_t inum;
{
struct inode *ip;
@@ -102,7 +102,7 @@ ext2_ihashlookup(dev, inum)
*/
int
ext2_ihashget(dev, inum, flags, vpp)
- dev_t dev;
+ struct cdev *dev;
ino_t inum;
int flags;
struct vnode **vpp;
diff --git a/sys/gnu/ext2fs/ext2_mount.h b/sys/gnu/ext2fs/ext2_mount.h
index e1ca44d..407ca8a 100644
--- a/sys/gnu/ext2fs/ext2_mount.h
+++ b/sys/gnu/ext2fs/ext2_mount.h
@@ -44,7 +44,7 @@ struct vnode;
/* This structure describes the ext2fs specific mount structure data. */
struct ext2mount {
struct mount *um_mountp; /* filesystem vfs structure */
- dev_t um_dev; /* device mounted */
+ struct cdev *um_dev; /* device mounted */
struct vnode *um_devvp; /* block device mounted vnode */
struct ext2_sb_info *um_e2fs; /* EXT2FS */
diff --git a/sys/gnu/ext2fs/ext2_vfsops.c b/sys/gnu/ext2fs/ext2_vfsops.c
index c91eaac..a745e6a 100644
--- a/sys/gnu/ext2fs/ext2_vfsops.c
+++ b/sys/gnu/ext2fs/ext2_vfsops.c
@@ -97,7 +97,7 @@ VFS_SET(ext2fs_vfsops, ext2fs, 0);
static int ext2fs_inode_hash_lock;
-static int ext2_check_sb_compat(struct ext2_super_block *es, dev_t dev,
+static int ext2_check_sb_compat(struct ext2_super_block *es, struct cdev *dev,
int ronly);
static int compute_sb_data(struct vnode * devvp,
struct ext2_super_block * es, struct ext2_sb_info * fs);
@@ -378,7 +378,7 @@ static int ext2_check_descriptors (struct ext2_sb_info * sb)
static int
ext2_check_sb_compat(es, dev, ronly)
struct ext2_super_block *es;
- dev_t dev;
+ struct cdev *dev;
int ronly;
{
@@ -635,7 +635,7 @@ ext2_mountfs(devvp, mp, td)
struct buf *bp;
struct ext2_sb_info *fs;
struct ext2_super_block * es;
- dev_t dev = devvp->v_rdev;
+ struct cdev *dev = devvp->v_rdev;
int error;
int ronly;
@@ -1000,7 +1000,7 @@ ext2_vget(mp, ino, flags, vpp)
struct ext2mount *ump;
struct buf *bp;
struct vnode *vp;
- dev_t dev;
+ struct cdev *dev;
int i, error;
int used_blocks;
diff --git a/sys/gnu/fs/ext2fs/ext2_extern.h b/sys/gnu/fs/ext2fs/ext2_extern.h
index 12ec524..45ba6b3 100644
--- a/sys/gnu/fs/ext2fs/ext2_extern.h
+++ b/sys/gnu/fs/ext2fs/ext2_extern.h
@@ -59,11 +59,11 @@ void ext2_dirbad(struct inode *ip, doff_t offset, char *how);
void ext2_ei2i(struct ext2_inode *, struct inode *);
int ext2_getlbns(struct vnode *, int32_t, struct indir *, int *);
void ext2_i2ei(struct inode *, struct ext2_inode *);
-int ext2_ihashget(dev_t, ino_t, int, struct vnode **);
+int ext2_ihashget(struct cdev *, ino_t, int, struct vnode **);
void ext2_ihashinit(void);
void ext2_ihashins(struct inode *);
struct vnode *
- ext2_ihashlookup(dev_t, ino_t);
+ ext2_ihashlookup(struct cdev *, ino_t);
void ext2_ihashrem(struct inode *);
void ext2_ihashuninit(void);
void ext2_itimes(struct vnode *vp);
diff --git a/sys/gnu/fs/ext2fs/ext2_mount.h b/sys/gnu/fs/ext2fs/ext2_mount.h
index e1ca44d..407ca8a 100644
--- a/sys/gnu/fs/ext2fs/ext2_mount.h
+++ b/sys/gnu/fs/ext2fs/ext2_mount.h
@@ -44,7 +44,7 @@ struct vnode;
/* This structure describes the ext2fs specific mount structure data. */
struct ext2mount {
struct mount *um_mountp; /* filesystem vfs structure */
- dev_t um_dev; /* device mounted */
+ struct cdev *um_dev; /* device mounted */
struct vnode *um_devvp; /* block device mounted vnode */
struct ext2_sb_info *um_e2fs; /* EXT2FS */
diff --git a/sys/gnu/fs/ext2fs/ext2_vfsops.c b/sys/gnu/fs/ext2fs/ext2_vfsops.c
index c91eaac..a745e6a 100644
--- a/sys/gnu/fs/ext2fs/ext2_vfsops.c
+++ b/sys/gnu/fs/ext2fs/ext2_vfsops.c
@@ -97,7 +97,7 @@ VFS_SET(ext2fs_vfsops, ext2fs, 0);
static int ext2fs_inode_hash_lock;
-static int ext2_check_sb_compat(struct ext2_super_block *es, dev_t dev,
+static int ext2_check_sb_compat(struct ext2_super_block *es, struct cdev *dev,
int ronly);
static int compute_sb_data(struct vnode * devvp,
struct ext2_super_block * es, struct ext2_sb_info * fs);
@@ -378,7 +378,7 @@ static int ext2_check_descriptors (struct ext2_sb_info * sb)
static int
ext2_check_sb_compat(es, dev, ronly)
struct ext2_super_block *es;
- dev_t dev;
+ struct cdev *dev;
int ronly;
{
@@ -635,7 +635,7 @@ ext2_mountfs(devvp, mp, td)
struct buf *bp;
struct ext2_sb_info *fs;
struct ext2_super_block * es;
- dev_t dev = devvp->v_rdev;
+ struct cdev *dev = devvp->v_rdev;
int error;
int ronly;
@@ -1000,7 +1000,7 @@ ext2_vget(mp, ino, flags, vpp)
struct ext2mount *ump;
struct buf *bp;
struct vnode *vp;
- dev_t dev;
+ struct cdev *dev;
int i, error;
int used_blocks;
diff --git a/sys/gnu/ext2fs/inode.h b/sys/gnu/ext2fs/inode.h
index b0f1625..cf5288a 100644
--- a/sys/gnu/ext2fs/inode.h
+++ b/sys/gnu/ext2fs/inode.h
@@ -65,7 +65,7 @@ struct inode {
struct vnode *i_vnode;/* Vnode associated with this inode. */
struct vnode *i_devvp;/* Vnode for block I/O. */
u_int32_t i_flag; /* flags, see below */
- dev_t i_dev; /* Device associated with the inode. */
+ struct cdev *i_dev; /* Device associated with the inode. */
ino_t i_number; /* The identity of the inode. */
struct ext2_sb_info *i_e2fs; /* EXT2FS */
@@ -110,7 +110,7 @@ struct inode {
* The di_db fields may be overlaid with other information for
* file types that do not have associated disk storage. Block
* and character devices overlay the first data block with their
* dev_t value. Short symbolic links place their path in the
* di_db area.
*/
#define i_shortlink i_db
@@ -110,7 +110,7 @@ struct inode {
* file types that do not have associated disk storage. Block
* and character devices overlay the first data block with their
- * dev_t value. Short symbolic links place their path in the
+ * struct cdev *value. Short symbolic links place their path in the
* di_db area.
*/
diff --git a/sys/gnu/fs/ext2fs/inode.h b/sys/gnu/fs/ext2fs/inode.h
index b0f1625..cf5288a 100644
--- a/sys/gnu/fs/ext2fs/inode.h
+++ b/sys/gnu/fs/ext2fs/inode.h
@@ -65,7 +65,7 @@ struct inode {
struct vnode *i_vnode;/* Vnode associated with this inode. */
struct vnode *i_devvp;/* Vnode for block I/O. */
u_int32_t i_flag; /* flags, see below */
- dev_t i_dev; /* Device associated with the inode. */
+ struct cdev *i_dev; /* Device associated with the inode. */
ino_t i_number; /* The identity of the inode. */
struct ext2_sb_info *i_e2fs; /* EXT2FS */
@@ -110,7 +110,7 @@ struct inode {
* The di_db fields may be overlaid with other information for
* file types that do not have associated disk storage. Block
* and character devices overlay the first data block with their
* dev_t value. Short symbolic links place their path in the
* di_db area.
*/
#define i_shortlink i_db
@@ -110,7 +110,7 @@ struct inode {
* file types that do not have associated disk storage. Block
* and character devices overlay the first data block with their
- * dev_t value. Short symbolic links place their path in the
+ * struct cdev *value. Short symbolic links place their path in the
* di_db area.
*/
OpenPOWER on IntegriCloud